==> illumination_0.1.20100319-1.tar.gz: illumination-0.1.20100319/include/Lum/TimeSpan.h <==
#ifndef LUM_TIMESPAN_H
#define LUM_TIMESPAN_H

/*
  This source is part of the Illumination library
  Copyright (C) 2009  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Dlg/ActionDialog.h>

#include <Lum/Model/Action.h>
#include <Lum/Model/Integer.h>

#include <Lum/Button.h>
#include <Lum/Text.h>

namespace Lum {

  class LUMAPI TimeSpan : public ControlComponent
  {
  private:
    Model::ActionRef ups[5];
    Model::ActionRef downs[5];
    Model::SizeTRef  digits[5];
    Text             *texts[5];
    Model::SizeTRef  model;

  public:
    TimeSpan();

    bool SetModel(Base::Model* model);

    void CalcSize();

    void Resync(Base::Model* model, const Base::ResyncMsg& msg);

    static TimeSpan* Create(Model::SizeT* model=NULL,
                            bool horizontalFlex=false, bool verticalFlex=false);
  };
}

#endif

==> illumination_0.2.20101220-1.tar.gz: illumination-0.2.20101220/include/Lum/TimeSpan.h <==
#ifndef LUM_TIMESPAN_H
#define LUM_TIMESPAN_H

/*
  This source is part of the Illumination library
  Copyright (C) 2009  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Dlg/ActionDialog.h>

#include <Lum/Model/Action.h>
#include <Lum/Model/Number.h>

#include <Lum/Button.h>
#include <Lum/Text.h>

namespace Lum {

  class LUMAPI TimeSpan : public ControlComponent
  {
  private:
    Model::ActionRef  ups[5];
    Model::ActionRef  downs[5];
    Model::ULongRef   digits[5];
    Text              *texts[5];
    Model::NumberRef  model;

  public:
    TimeSpan();

    bool SetModel(Base::Model* model);

    void CalcSize();

    void Resync(Base::Model* model, const Base::ResyncMsg& msg);

    static TimeSpan* Create(Model::Number* model=NULL,
                            bool horizontalFlex=false, bool verticalFlex=false);
  };
}

#endif
